This package is composed of two high-performance simulators:

A Ribosome simulator, that, given a codon and tRNA concentrations, simulates the internal reactions of the ribosome and their times. It can produce complete data about these reacions: The state of the ribosome, the time it took for each reaction to happen, their frequency, etc.

The other simulator is an elongation simulator: it simulates ribosomes intiating, elongating and terminating a given mRNA. It simulates collisions, ribosome stalling, etc. This tool can also perform simulations in parallel and produce complete information about all ribosomes, and their positions in the mRNA contruct.
